package cn.estsh.i3plus.pojo.base.bean;

import java.util.HashMap;

/**
 * @Description : hql脚本封装类
 * @Reference :
 * @Author : alwaysfrin
 * @CreateDate : 2019-03-29 15:57
 * @Modify:
 **/
public class DdlPackBean {

    /**
     * String 为属性及条件
     * example： and name = :name
     * and num > :num  or .....
     * Object 为属性值
     * example: 值
     *
     * dao层将map进行解封，hql部分直接添加key值，然后再进行value赋值
     */
    private HashMap<String,Object> hqlPreparedMap;

    //是否是hql
    private boolean isHql;

    //手动hql，尽量避免直接传参，使用？代替
    private String hqlAppend;

    //where后跟着的hql/sql
    private StringBuilder whereAppend;

    //排序内容
    private String orderByStr;

    //需要拼接的hql
    private StringBuilder sb = null;

    public DdlPackBean(){
        this.isHql = true;
        whereAppend = new StringBuilder();
        hqlPreparedMap = new HashMap<>();
    }

    public DdlPackBean(boolean isHql){
        this.isHql = isHql;
        whereAppend = new StringBuilder();
        hqlPreparedMap = new HashMap<>();
    }

    public boolean isHql() {
        return isHql;
    }

    public void setHql(boolean hql) {
        isHql = hql;
    }

    public String getOrderByStr() {
        return orderByStr;
    }

    public void setOrderByStr(String orderByStr) {
        this.orderByStr = orderByStr;
    }

    public String getHqlAppend() {
        return hqlAppend;
    }

    public void setHqlAppend(String hqlAppend) {
        this.hqlAppend = hqlAppend;
    }

    public String getWhereAppend() {
        return whereAppend.toString();
    }

    public void setWhereAppend(String whereAppend) {
        this.whereAppend = new StringBuilder(whereAppend);
    }

    public HashMap<String, Object> getHqlPreparedMap() {
        return hqlPreparedMap;
    }

    /**
     * 添加查询条件
     * @param hql
     * @param val
     */
    public void addColumnQuery(String column,String hql,Object val){
        if(hqlPreparedMap == null){
            hqlPreparedMap = new HashMap<>();
        }
        if(column != null && val != null) {
            hqlPreparedMap.put(column, val);
        }

        whereAppend.append(hql);
    }

    /**
     * 需要查询属性的数量
     * @return
     */
    public int getColumnSize(){
        return hqlPreparedMap.size();
    }

    /**
     * 获取包含hql的最终的ddl
     * @return
     */
    public String getPackedHqlAll(){
        sb = new StringBuilder();
        if(hqlAppend != null){
            sb.append(hqlAppend);
        }
        if(whereAppend != null){
            sb.append(whereAppend);
        }
        if(orderByStr != null){
            sb.append(orderByStr);
        }
        return sb.toString();
    }

    /**
     * 获取最终的ddl
     * @return
     */
    public String getPackedHql(){
        sb = new StringBuilder();
        if(whereAppend != null){
            sb.append(whereAppend);
        }
        if(orderByStr != null){
            sb.append(orderByStr);
        }
        return sb.toString();
    }
}
