package cn.estsh.i3plus.pojo.mes.sqlpack;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.MesEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.*;
import org.apache.commons.lang3.StringUtils;

/**
 * @Description:
 * @Reference: Mes 条件封装
 * @Author: Crish
 * @CreateDate:2019-04-22-14:58
 * @Modify:
 **/
public class MesHqlPack {

    /**
     * 通用查询条件
     *
     * @param organizeCode
     * @return
     */
    public static DdlPackBean getAllBaseData(String organizeCode) {
        DdlPackBean packBean = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(organizeCode, "organizeCode", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_VAILD.VAILD.getValue(), "isValid", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_DEAL.NO.getValue(), "isDeleted", packBean);
        return packBean;
    }

    /**
     * 生产计划查询条件封装
     *
     * @param mesPlanOrder
     * @return
     */
    public static DdlPackBean getPlanOrderCondition(MesPlanOrder mesPlanOrder, String organizeCode) {
        DdlPackBean packBean = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(organizeCode, "organizeCode", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_VAILD.VAILD.getValue(), "isValid", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_DEAL.NO.getValue(), "isDeleted", packBean);

        if (StringUtils.isNotEmpty(mesPlanOrder.getOrderNo())) {
            DdlPreparedPack.getStringLikerPack(mesPlanOrder.getOrderNo(), "orderNo", packBean);
        }
        if (StringUtils.isNotEmpty(mesPlanOrder.getPartNo())) {
            DdlPreparedPack.getStringLikerPack(mesPlanOrder.getPartNo(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(mesPlanOrder.getPlanType() + "") && mesPlanOrder.getPlanTypeVal() != 0) {
            DdlPreparedPack.getNumEqualPack(mesPlanOrder.getPlanType(), "planType", packBean);
        }
        if (StringUtils.isNotEmpty(mesPlanOrder.getStatus() + "") && mesPlanOrder.getStatusVal() != 0) {
            DdlPreparedPack.getNumEqualPack(mesPlanOrder.getStatus(), "status", packBean);
        }
        if (StringUtils.isNotEmpty(mesPlanOrder.getCreateUser())) {
            DdlPreparedPack.getStringEqualPack(mesPlanOrder.getCreateUser(), "createUser", packBean);
        }

        // 时间段查询
        DdlPreparedPack.timeBuilder(
                mesPlanOrder.getStartTimeStart(),
                mesPlanOrder.getStartTimeEnd(),
                "startTime", packBean, true);
        DdlPreparedPack.timeBuilder(
                mesPlanOrder.getEndTimeStart(),
                mesPlanOrder.getEndTimeEnd(),
                "endTime", packBean, true);
        DdlPreparedPack.timeBuilder(
                mesPlanOrder.getCreateDateTimeStart(),
                mesPlanOrder.getCreateDateTimeEnd(),
                "createDatetime", packBean, true);

        // 排序
        DdlPreparedPack.getOrderDefault(mesPlanOrder);
        DdlPreparedPack.getOrderByPack(new Object[]{"2"}, new String[]{mesPlanOrder.getOrderByParam()}, packBean);
        return packBean;
    }

    /**
     * 物料信息查询条件封装
     *
     * @param mesPart
     * @return
     */
    public static DdlPackBean getPartCondition(MesPart mesPart, String organizeCode) {
        DdlPackBean packBean = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(organizeCode, "organizeCode", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_VAILD.VAILD.getValue(), "isValid", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_DEAL.NO.getValue(), "isDeleted", packBean);

        if (StringUtils.isNotEmpty(mesPart.getPartNo())) {
            DdlPreparedPack.getStringLikerPack(mesPart.getPartNo(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(mesPart.getPartName())) {
            DdlPreparedPack.getStringLikerPack(mesPart.getPartName(), "partName", packBean);
        }
        if (StringUtils.isNotEmpty(mesPart.getCategoryCode1())) {
            DdlPreparedPack.getStringEqualPack(mesPart.getCategoryCode1(), "categoryCode1", packBean);
        }
        if (StringUtils.isNotEmpty(mesPart.getCategoryCode2())) {
            DdlPreparedPack.getStringEqualPack(mesPart.getCategoryCode2(), "categoryCode2", packBean);
        }
        if (StringUtils.isNotEmpty(mesPart.getCategoryCode3())) {
            DdlPreparedPack.getStringEqualPack(mesPart.getCategoryCode3(), "categoryCode3", packBean);
        }

        DdlPreparedPack.getOrderDefault(mesPart);
        DdlPreparedPack.getOrderByPack(new Object[]{"2"}, new String[]{mesPart.getOrderByParam()}, packBean);
        return packBean;
    }

    /**
     * 生产工单查询条件封装
     *
     * @param mesWorkOrder
     * @return
     */
    public static DdlPackBean getWorkOrderCondition(MesWorkOrder mesWorkOrder, String organizeCode) {
        DdlPackBean packBean = getAllBaseData(organizeCode);
        if (StringUtils.isNotEmpty(mesWorkOrder.getOrderNo())) {
            DdlPreparedPack.getStringLikerPack(mesWorkOrder.getOrderNo(), "orderNo", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getPartNo())) {
            DdlPreparedPack.getStringLikerPack(mesWorkOrder.getPartNo(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getWorkOrderStatus() + "") && mesWorkOrder.getWorkOrderStatusVal() != 0) {
            DdlPreparedPack.getNumEqualPack(mesWorkOrder.getWorkOrderStatus(), "workOrderStatus", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getWorkCenterCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkOrder.getWorkCenterCode(), "workCenterCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getWorkCellCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkOrder.getWorkCellCode(), "workCellCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getWorkOrderType() + "") && mesWorkOrder.getWorkOrderTypeVal() != 0) {
            DdlPreparedPack.getNumEqualPack(mesWorkOrder.getWorkOrderType(), "workOrderType", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getProdCfgCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkOrder.getProdCfgCode(), "prodCfgCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkOrder.getPlanOrderNo())) {
            DdlPreparedPack.getStringEqualPack(mesWorkOrder.getPlanOrderNo(), "planOrderNo", packBean);
        }

        // 时间段查询
//        DdlPreparedPack.timeBuilder(
//                mesWorkOrder.getStartTimeStart(),
//                mesWorkOrder.getStartTimeEnd(),
//                "startTime", packBean, true);
//        DdlPreparedPack.timeBuilder(
//                mesWorkOrder.getEndTimeStart(),
//                mesWorkOrder.getEndTimeEnd(),
//                "endTime", packBean, true);
        DdlPreparedPack.getOrderDefault(mesWorkOrder);
        DdlPreparedPack.getOrderByPack(new Object[]{"2"}, new String[]{mesWorkOrder.getOrderByParam()}, packBean);
        return packBean;
    }

    /**
     * 生产队列查询条件封装
     *
     * @param mesQueueOrder
     * @return
     */
    public static DdlPackBean getQueueOrder(MesQueueOrder mesQueueOrder, String organizeCode) {
        DdlPackBean packBean = getAllBaseData(organizeCode);
        if (StringUtils.isNotEmpty(mesQueueOrder.getCustFlagNoStart())) {
            DdlPreparedPack.getStringBiggerPack(mesQueueOrder.getCustFlagNoStart(), "custFlagNo", packBean);
        }

        if (StringUtils.isNotEmpty(mesQueueOrder.getCustFlagNoEnd() + "")) {
            DdlPreparedPack.getStringSmallerPack(mesQueueOrder.getCustFlagNoEnd(), "custFlagNo", packBean);
        }

        if (StringUtils.isNotEmpty(mesQueueOrder.getOrderNo() + "")) {
            DdlPreparedPack.getStringLikerPack(mesQueueOrder.getOrderNo(), "orderNo", packBean);
        }

        // 只查询创建状态的队列
        DdlPreparedPack.getNumEqualPack(MesEnumUtil.QUEUE_ORDER_STATUS.NORMAL.getValue(), "status", packBean);

        // 时间段查询
        DdlPreparedPack.timeBuilder(
                mesQueueOrder.getCreateDateTimeStart(),
                mesQueueOrder.getCreateDateTimeEnd(),
                "createDatetime", packBean, true);

        // DdlPreparedPack.getOrderDefault(mesQueueOrder);
        // 按照队列序列号倒序
        DdlPreparedPack.getOrderByPack(new Object[]{"2"}, new String[]{"seq"}, packBean);
        return packBean;
    }

    /**
     * 通用查询条件
     *
     * @param organizeCode
     * @return
     */
    public static DdlPackBean getAllBaseDataByNormalPro(BaseBean baseBean, String organizeCode) {
        DdlPackBean packBean = new DdlPackBean();
        DdlPreparedPack.getStringEqualPack(organizeCode, "organizeCode", packBean);
        DdlPreparedPack.getNumEqualPack(baseBean.getIsValid(), "isValid", packBean);
        DdlPreparedPack.getNumEqualPack(CommonEnumUtil.IS_DEAL.NO.getValue(), "isDeleted", packBean);
        return packBean;
    }

    /**
     * MES区域信息查询条件封装
     *
     * @param mesArea
     * @return
     */
    public static DdlPackBean getMesArea(MesArea mesArea, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(mesArea, organizeCode);
        if (StringUtils.isNotEmpty(mesArea.getAreaCode())) {
            DdlPreparedPack.getStringEqualPack(mesArea.getAreaCode(), "areaCode", packBean);
        }

        return packBean;
    }

    /**
     * MES工作中心信息查询条件封装
     *
     * @param mesWorkCenter
     * @return
     */
    public static DdlPackBean getMesWorkCenter(MesWorkCenter mesWorkCenter, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(mesWorkCenter, organizeCode);
        if (StringUtils.isNotEmpty(mesWorkCenter.getWorkCenterCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkCenter.getWorkCenterCode(), "workCenterCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkCenter.getAreaCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkCenter.getAreaCode(), "areaCode", packBean);
        }

        return packBean;
    }

    /**
     * MES工作单元信息查询条件封装
     *
     * @param mesWorkCell
     * @return
     */
    public static DdlPackBean getMesWorkCell(MesWorkCell mesWorkCell, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(mesWorkCell, organizeCode);
        if (StringUtils.isNotEmpty(mesWorkCell.getWorkCenterCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkCell.getWorkCenterCode(), "workCenterCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkCell.getAreaCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkCell.getAreaCode(), "areaCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesWorkCell.getWorkCellCode())) {
            DdlPreparedPack.getStringEqualPack(mesWorkCell.getWorkCellCode(), "workCellCode", packBean);
        }

        return packBean;
    }

    /**
     * MES设备信息查询条件封装
     * @param mesEquipment
     * @return
     */
    public static DdlPackBean getMesEquipment(MesEquipment mesEquipment, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(mesEquipment, organizeCode);
        if (StringUtils.isNotEmpty(mesEquipment.getWorkCellCode())){
            DdlPreparedPack.getStringEqualPack(mesEquipment.getWorkCellCode(), "workCellCode", packBean);
        }
        if (StringUtils.isNotEmpty(mesEquipment.getEquipmentCode())){
            DdlPreparedPack.getStringEqualPack(mesEquipment.getEquipmentCode(), "equipmentCode", packBean);
        }

        return packBean;
    }

    /**
     * 流程查询条件封装
     *
     * @param mesRoute
     * @return
     */
    public static DdlPackBean packHqlMesRoute(MesRoute mesRoute, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(mesRoute, organizeCode);
        DdlPreparedPack.getStringLikerPack(mesRoute.getRouteCode(), "routeCode", packBean);
        DdlPreparedPack.getStringLikerPack(mesRoute.getRouteName(), "routeName", packBean);
        packBean.setOrderByStr(mesRoute.orderBy());
        return packBean;
    }
    /**
     * 产品流程配置查询条件封装
     *
     * @param mesProdRouteCfg
     * @param organizeCode
     * @return
     */
    public static DdlPackBean packHqlMesProdRouteCfg(MesProdRouteCfg mesProdRouteCfg, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(mesProdRouteCfg, organizeCode);
        DdlPreparedPack.getStringEqualPack(mesProdRouteCfg.getPartNo(), "partNo", packBean);
        DdlPreparedPack.getStringEqualPack(mesProdRouteCfg.getWorkCenterCode(), "workCenterCode", packBean);
        DdlPreparedPack.getStringEqualPack(mesProdRouteCfg.getRouteCode(), "routeCode", packBean);
        packBean.setOrderByStr(mesProdRouteCfg.orderBy());
        return packBean;
    }

    /**
     * MES班次信息查询条件封装
     * @param shift
     * @return
     */
    public static DdlPackBean getMesShift(MesShift shift, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(shift, organizeCode);
        if (StringUtils.isNotEmpty(shift.getShiftCode())){
            DdlPreparedPack.getStringEqualPack(shift.getShiftCode(), "shiftCode", packBean);
        }
        if (StringUtils.isNotEmpty(shift.getShiftName())){
            DdlPreparedPack.getStringLikerPack(shift.getShiftName(), "shiftName", packBean);
        }
        if (StringUtils.isNotEmpty(shift.getWorkCenterCode())){
            DdlPreparedPack.getStringEqualPack(shift.getWorkCenterCode(), "workCenterCode", packBean);
        }

        return packBean;
    }

    /**
     * MES班次休息信息查询条件封装
     * @param shiftRest
     * @return
     */
    public static DdlPackBean getMesShiftRest(MesShiftRest shiftRest, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(shiftRest, organizeCode);
        if (StringUtils.isNotEmpty(shiftRest.getWorkCenterCode())){
            DdlPreparedPack.getStringEqualPack(shiftRest.getWorkCenterCode(), "workCenterCode", packBean);
        }
        if (StringUtils.isNotEmpty(shiftRest.getShiftCode())){
            DdlPreparedPack.getStringEqualPack(shiftRest.getShiftCode(), "shiftCode", packBean);
        }

        return packBean;
    }

    /**
     * MES工序信息查询条件封装
     * @param process
     * @return
     */
    public static DdlPackBean getMesProcess(MesProcess process, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(process, organizeCode);
        if (StringUtils.isNotEmpty(process.getProcessCode())){
            DdlPreparedPack.getStringEqualPack(process.getProcessCode(), "processCode", packBean);
        }
        if (StringUtils.isNotEmpty(process.getProcessName())){
            DdlPreparedPack.getStringLikerPack(process.getProcessName(), "processName", packBean);
        }

        return packBean;
    }

    /**
     * MES工步信息查询条件封装
     * @param step
     * @return
     */
    public static DdlPackBean getMesStep(MesStep step, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(step, organizeCode);
        if (StringUtils.isNotEmpty(step.getStepCode())){
            DdlPreparedPack.getStringEqualPack(step.getStepCode(), "stepCode", packBean);
        }
        if (StringUtils.isNotEmpty(step.getStepName())){
            DdlPreparedPack.getStringLikerPack(step.getStepName(), "stepName", packBean);
        }
        if (StringUtils.isNotEmpty(step.getStepType())){
            DdlPreparedPack.getStringLikerPack(step.getStepType(), "stepType", packBean);
        }

        return packBean;
    }

    /**
     * MES工步参数信息查询条件封装
     * @param stepParam
     * @return
     */
    public static DdlPackBean getMesStepParam(MesStepParam stepParam, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(stepParam, organizeCode);
        if (StringUtils.isNotEmpty(stepParam.getStepCode())){
            DdlPreparedPack.getStringEqualPack(stepParam.getStepCode(), "stepCode", packBean);
        }
        if (StringUtils.isNotEmpty(stepParam.getParamCode())){
            DdlPreparedPack.getStringEqualPack(stepParam.getParamCode(), "paramCode", packBean);
        }
        if (StringUtils.isNotEmpty(stepParam.getParamName())){
            DdlPreparedPack.getStringLikerPack(stepParam.getParamName(), "paramName", packBean);
        }

        return packBean;
    }

    /**
     * MES工序工作单元对应关系查询条件封装
     * @param routeProcessCell
     * @return
     */
    public static DdlPackBean getMesRouteProcessCell(MesRouteProcessCell routeProcessCell, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(routeProcessCell, organizeCode);
        if (StringUtils.isNotEmpty(routeProcessCell.getRouteCode())){
            DdlPreparedPack.getStringEqualPack(routeProcessCell.getRouteCode(), "routeCode", packBean);
        }
        if (StringUtils.isNotEmpty(routeProcessCell.getProcessCode())){
            DdlPreparedPack.getStringEqualPack(routeProcessCell.getProcessCode(), "processCode", packBean);
        }
        if (StringUtils.isNotEmpty(routeProcessCell.getWorkCellCode())){
            DdlPreparedPack.getStringEqualPack(routeProcessCell.getWorkCellCode(), "workCellCode", packBean);
        }
        if (StringUtils.isNotEmpty(routeProcessCell.getWorkCenterCode())){
            DdlPreparedPack.getStringEqualPack(routeProcessCell.getWorkCenterCode(), "workCenterCode", packBean);
        }

        return packBean;
    }

    /**
     * MES BOM信息查询条件封装
     * @param bom
     * @return
     */
    public static DdlPackBean getMesBom(MesBom bom, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(bom, organizeCode);
        if (StringUtils.isNotEmpty(bom.getPartNo())){
            DdlPreparedPack.getStringEqualPack(bom.getPartNo(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(bom.getItemPartNo())){
            DdlPreparedPack.getStringEqualPack(bom.getItemPartNo(), "itemPartNo", packBean);
        }
        if (StringUtils.isNotEmpty(bom.getBomVersion())){
            DdlPreparedPack.getStringEqualPack(bom.getBomVersion(), "bomVersion", packBean);
        }

        return packBean;
    }

    /**
     * MES工序BOM信息查询条件封装
     * @param processBom
     * @return
     */
    public static DdlPackBean getMesProcessBom(MesProcessBom processBom, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(processBom, organizeCode);
        if (StringUtils.isNotEmpty(processBom.getPartNo())){
            DdlPreparedPack.getStringEqualPack(processBom.getPartNo(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(processBom.getItemPartNo())){
            DdlPreparedPack.getStringEqualPack(processBom.getItemPartNo(), "itemPartNo", packBean);
        }
        if (StringUtils.isNotEmpty(processBom.getProcessCode())){
            DdlPreparedPack.getStringEqualPack(processBom.getProcessCode(), "processCode", packBean);
        }

        return packBean;
    }

    /**
     * MES 客户信息查询条件封装
     * @param customer
     * @return
     */
    public static DdlPackBean getMesCustomer(MesCustomer customer, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(customer, organizeCode);
        if (StringUtils.isNotEmpty(customer.getCustomerCode())){
            DdlPreparedPack.getStringEqualPack(customer.getCustomerCode(), "customerCode", packBean);
        }
        if (StringUtils.isNotEmpty(customer.getCustomerName())){
            DdlPreparedPack.getStringLikerPack(customer.getCustomerName(), "customerName", packBean);
        }

        return packBean;
    }

    /**
     * MES 客户产线信息查询条件封装
     * @param custProdLine
     * @return
     */
    public static DdlPackBean getMesCustProdLine(MesCustProdLine custProdLine, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(custProdLine, organizeCode);
        if (StringUtils.isNotEmpty(custProdLine.getCustProdLineCode())){
            DdlPreparedPack.getStringEqualPack(custProdLine.getCustProdLineCode(), "custProdLineCode", packBean);
        }
        if (StringUtils.isNotEmpty(custProdLine.getCustProdLineName())){
            DdlPreparedPack.getStringLikerPack(custProdLine.getCustProdLineName(), "custProdLineName", packBean);
        }

        return packBean;
    }

    /**
     * MES 客户零件关系信息查询条件封装
     * @param customerPart
     * @return
     */
    public static DdlPackBean getMesCustomerPart(MesCustomerPart customerPart, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(customerPart, organizeCode);
        if (StringUtils.isNotEmpty(customerPart.getCustomerCode())){
            DdlPreparedPack.getStringEqualPack(customerPart.getCustomerCode(), "customerCode", packBean);
        }
        if (StringUtils.isNotEmpty(customerPart.getPartNo())){
            DdlPreparedPack.getStringEqualPack(customerPart.getPartNo(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(customerPart.getCustomerPartNo())){
            DdlPreparedPack.getStringEqualPack(customerPart.getCustomerPartNo(), "customerPartNo", packBean);
        }

        return packBean;
    }

    /**
     * MES 设备关键数据信息查询条件封装
     * @param keyData
     * @return
     */
    public static DdlPackBean getMesKeyData(MesKeyData keyData, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(keyData, organizeCode);
        if (StringUtils.isNotEmpty(keyData.getKeyDataCode())){
            DdlPreparedPack.getStringEqualPack(keyData.getKeyDataCode(), "keyDataCode", packBean);
        }
        if (StringUtils.isNotEmpty(keyData.getKeyDataName())){
            DdlPreparedPack.getStringEqualPack(keyData.getKeyDataName(), "keyDataName", packBean);
        }

        return packBean;
    }

    /**
     * MES 物料关键数据关系信息查询条件封装
     * @param kpData
     * @return
     */
    public static DdlPackBean getMesKpData(MesKpData kpData, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(kpData, organizeCode);
        if (StringUtils.isNotEmpty(kpData.getPartNo())){
            DdlPreparedPack.getStringEqualPack(kpData.getKeyDataCode(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(kpData.getKeyDataCode())){
            DdlPreparedPack.getStringEqualPack(kpData.getKeyDataCode(), "keyDataCode", packBean);
        }

        return packBean;
    }

    /**
     * MES 产品配置类型信息查询条件封装
     * @param prodCfgType
     * @return
     */
    public static DdlPackBean getMesProdCfgType(MesProdCfgType prodCfgType, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(prodCfgType, organizeCode);
        if (StringUtils.isNotEmpty(prodCfgType.getProdCfgTypeCode())){
            DdlPreparedPack.getStringEqualPack(prodCfgType.getProdCfgTypeCode(), "prodCfgTypeCode", packBean);
        }
        if (StringUtils.isNotEmpty(prodCfgType.getProdCfgTypeName())){
            DdlPreparedPack.getStringEqualPack(prodCfgType.getProdCfgTypeName(), "prodCfgTypeName", packBean);
        }

        return packBean;
    }

    /**
     * MES 产品配置信息查询条件封装
     * @param prodCfg
     * @return
     */
    public static DdlPackBean getMesProdCfg(MesProdCfg prodCfg, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(prodCfg, organizeCode);
        if (StringUtils.isNotEmpty(prodCfg.getProdCfgCode())){
            DdlPreparedPack.getStringEqualPack(prodCfg.getProdCfgCode(), "prodCfgCode", packBean);
        }
        if (StringUtils.isNotEmpty(prodCfg.getProdCfgName())){
            DdlPreparedPack.getStringLikerPack(prodCfg.getProdCfgName(), "prodCfgName", packBean);
        }
        if (StringUtils.isNotEmpty(prodCfg.getProdCfgTypeCode())){
            DdlPreparedPack.getStringEqualPack(prodCfg.getProdCfgTypeCode(), "prodCfgTypeCode", packBean);
        }

        return packBean;
    }

    /**
     * MES 产品配置关系信息查询条件封装
     * @param prodCfgDetail
     * @return
     */
    public static DdlPackBean getMesProdCfgDetail(MesProdCfgDetail prodCfgDetail, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(prodCfgDetail, organizeCode);
        if (StringUtils.isNotEmpty(prodCfgDetail.getProdCfgCode())){
            DdlPreparedPack.getStringEqualPack(prodCfgDetail.getProdCfgCode(), "prodCfgCode", packBean);
        }
        if (StringUtils.isNotEmpty(prodCfgDetail.getPartNo())){
            DdlPreparedPack.getStringEqualPack(prodCfgDetail.getPartNo(), "partNo", packBean);
        }

        return packBean;
    }

    /**
     * MES 物料信息查询条件封装
     * @param part
     * @return
     */
    public static DdlPackBean getMesPart(MesPart part, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(part, organizeCode);
        if (StringUtils.isNotEmpty(part.getPartNo())){
            DdlPreparedPack.getStringEqualPack(part.getPartNo(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(part.getPartName())){
            DdlPreparedPack.getStringLikerPack(part.getPartName(), "partName", packBean);
        }
        if (StringUtils.isNotEmpty(part.getCategoryCode1())){
            DdlPreparedPack.getStringEqualPack(part.getCategoryCode1(), "categoryCode1", packBean);
        }
        if (StringUtils.isNotEmpty(part.getCategoryCode2())){
            DdlPreparedPack.getStringEqualPack(part.getCategoryCode2(), "categoryCode2", packBean);
        }
        if (StringUtils.isNotEmpty(part.getCategoryCode3())){
            DdlPreparedPack.getStringEqualPack(part.getCategoryCode3(), "categoryCode3", packBean);
        }

        return packBean;
    }

    /**
     * MES 物料分类信息查询条件封装
     * @param partCategory
     * @return
     */
    public static DdlPackBean getMesPartCategory(MesPartCategory partCategory, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(partCategory, organizeCode);
        if (StringUtils.isNotEmpty(partCategory.getCategoryCode())){
            DdlPreparedPack.getStringEqualPack(partCategory.getCategoryCode(), "categoryCode", packBean);
        }
        if (StringUtils.isNotEmpty(partCategory.getCategoryName())){
            DdlPreparedPack.getStringLikerPack(partCategory.getCategoryName(), "categoryName", packBean);
        }

        return packBean;
    }

    /**
     * MES 包装规格信息查询条件封装
     * @param packSpec
     * @return
     */
    public static DdlPackBean getMesPackSpec(MesPackSpec packSpec, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(packSpec, organizeCode);
        if (StringUtils.isNotEmpty(packSpec.getSpecCode())){
            DdlPreparedPack.getStringEqualPack(packSpec.getSpecCode(), "specCode", packBean);
        }
        if (StringUtils.isNotEmpty(packSpec.getSpecName())){
            DdlPreparedPack.getStringLikerPack(packSpec.getSpecName(), "specName", packBean);
        }
        if (StringUtils.isNotEmpty(packSpec.getParentSpec())){
            DdlPreparedPack.getStringEqualPack(packSpec.getParentSpec(), "parentSpec", packBean);
        }

        return packBean;
    }

    /**
     * MES 产品类型信息查询条件封装
     * @param produceCategory
     * @return
     */
    public static DdlPackBean getMesProduceCategory(MesProduceCategory produceCategory, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(produceCategory, organizeCode);
        if (StringUtils.isNotEmpty(produceCategory.getProduceCategoryCode())){
            DdlPreparedPack.getStringEqualPack(produceCategory.getProduceCategoryCode(), "produceCategoryCode", packBean);
        }
        if (StringUtils.isNotEmpty(produceCategory.getProduceCategoryName())){
            DdlPreparedPack.getStringLikerPack(produceCategory.getProduceCategoryName(), "produceCategoryName", packBean);
        }

        return packBean;
    }

    /**
     * MES 关键件条码规则信息查询条件封装
     * @param kpsnRule
     * @return
     */
    public static DdlPackBean getMesKpsnRule(MesKpsnRule kpsnRule, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(kpsnRule, organizeCode);
        if (StringUtils.isNotEmpty(kpsnRule.getPartNo())){
            DdlPreparedPack.getStringEqualPack(kpsnRule.getPartNo(), "partNo", packBean);
        }

        return packBean;
    }

    /**
     * MES 产品排程清单信息查询条件封装
     * @param partScheduleBom
     * @return
     */
    public static DdlPackBean getMesPartScheduleBom(MesPartScheduleBom partScheduleBom, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(partScheduleBom, organizeCode);
        if (StringUtils.isNotEmpty(partScheduleBom.getPartNo())){
            DdlPreparedPack.getStringEqualPack(partScheduleBom.getPartNo(), "partNo", packBean);
        }
        if (StringUtils.isNotEmpty(partScheduleBom.getItemPartNo())){
            DdlPreparedPack.getStringLikerPack(partScheduleBom.getItemPartNo(), "itemPartNo", packBean);
        }

        return packBean;
    }

    /**
     * MES对象与dao对应关系查询条件封装
     * @param objectDao
     * @return
     */
    public static DdlPackBean getMesObjectDao(MesObjectDao objectDao, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(objectDao, organizeCode);
        if (StringUtils.isNotEmpty(objectDao.getObjectCode())){
            DdlPreparedPack.getStringEqualPack(objectDao.getObjectCode(), "objectCode", packBean);
        }
        if (StringUtils.isNotEmpty(objectDao.getDaoClass())){
            DdlPreparedPack.getStringEqualPack(objectDao.getDaoClass(), "daoClass", packBean);
        }

        return packBean;
    }

    /**
     * MES-PCN同步配置查询条件封装
     * @param pcnSyncCfg
     * @return
     */
    public static DdlPackBean getMesPcnSyncCfg(MesPcnSyncCfg pcnSyncCfg, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(pcnSyncCfg, organizeCode);
        if (StringUtils.isNotEmpty(pcnSyncCfg.getObjectCode())){
            DdlPreparedPack.getStringEqualPack(pcnSyncCfg.getObjectCode(), "objectCode", packBean);
        }
        if (StringUtils.isNotEmpty(pcnSyncCfg.getPcnCode())){
            DdlPreparedPack.getStringEqualPack(pcnSyncCfg.getPcnCode(), "pcnCode", packBean);
        }
        if (null != pcnSyncCfg.getSyncType()){
            DdlPreparedPack.getNumEqualPack(pcnSyncCfg.getSyncType(), "syncType", packBean);
        }

        return packBean;
    }

    /**
     * MES工作单元参数配置查询条件封装
     * @param workCellParamCfg
     * @return
     */
    public static DdlPackBean getMesWorkCellParamCfg(MesWorkCellParamCfg workCellParamCfg, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(workCellParamCfg, organizeCode);
        if (StringUtils.isNotEmpty(workCellParamCfg.getWorkCellCode())){
            DdlPreparedPack.getStringEqualPack(workCellParamCfg.getWorkCellCode(), "workCellCode", packBean);
        }
        if (StringUtils.isNotEmpty(workCellParamCfg.getParamCode())){
            DdlPreparedPack.getStringEqualPack(workCellParamCfg.getParamCode(), "paramCode", packBean);
        }

        return packBean;
    }

    /**
     * MES工作单元队列查询条件封装
     * @param workCellPoint
     * @return
     */
    public static DdlPackBean getMesWorkCellPoint(MesWorkCellPoint workCellPoint, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(workCellPoint, organizeCode);
        if (StringUtils.isNotEmpty(workCellPoint.getWorkCellCode())){
            DdlPreparedPack.getStringEqualPack(workCellPoint.getWorkCellCode(), "workCellCode", packBean);
        }
        return packBean;
    }

    /**
     * PLC设备信息配置查询条件封装
     * @param plcConfigure
     * @return
     */
    public static DdlPackBean getMesPLCConfigure(MesPLCConfigure plcConfigure, String organizeCode) {
        DdlPackBean packBean = getAllBaseDataByNormalPro(plcConfigure, organizeCode);
        if (StringUtils.isNotEmpty(plcConfigure.getAreaCode())){
            DdlPreparedPack.getStringEqualPack(plcConfigure.getAreaCode(), "areaCode", packBean);
        }
        if (StringUtils.isNotEmpty(plcConfigure.getWorkCenterCode())){
            DdlPreparedPack.getStringEqualPack(plcConfigure.getWorkCenterCode(), "workCenterCode", packBean);
        }
        if (StringUtils.isNotEmpty(plcConfigure.getWorkCellCode())){
            DdlPreparedPack.getStringEqualPack(plcConfigure.getWorkCellCode(), "workCellCode", packBean);
        }
        return packBean;
    }
}
