package cn.estsh.i3plus.pojo.wms.bean;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.ColumnDefault;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * @Description : PO条码表
 * @Reference :
 * @Author : hansen.ke
 * @CreateDate : 2018-11-28 15:20
 * @Modify:
 *  2018-12-10 10:39:46 Test
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Table(name="WMS_DOC_PO_SN", indexes = {
        @Index(columnList = "ORDER_NO"),
        @Index(columnList = "PART_NO"),
        @Index(columnList = "SN_1D"),
        @Index(columnList = "SN_2D"),
        @Index(columnList = "ORGANIZE_CODE")
})
@Api("PO条码信息")
public class WmsPoSn extends BaseBean {

    @Column(name="ORDER_NO")
    @ApiParam("订单号")
    public String orderNo;

    @Column(name="ITEM")
    @ApiParam("行号")
    public String item;

    @Column(name="PART_NO")
    @ApiParam("物料编码")
    public String partNo;

    @Column(name="PART_NAME_RDD")
    @ApiParam("物料名称")
    public String partNameRdd;

    @Column(name="QTY")
    @ColumnDefault("0")
    @ApiParam(value = "数量", example = "0")
    public Double qty;


    @Column(name="UNIT")
    @ApiParam("单位")
    public String unit;

    /**
     * 状态:10 = 创建，20 = 已打印，30 = 已收货
     */
    @Column(name="SN_STATUS")
    @ApiParam(value = "状态", example = "10")
    public Integer snStatus;

    @Column(name="PACKAGE")
    @ApiParam("包装名称")
    public String packAge;

    @Column(name="SN_1D")
    @ApiParam("一维条码")
    public String snOneBarCode;

    @Column(name="SN_2D")
    @ApiParam("二维条码")
    public String snTwoBarCode;

    @Column(name="GROUP_NO")
    @ApiParam("组条码")
    public String groupNo;

    @Column(name="REC_QTY")
    @ColumnDefault("0")
    @ApiParam(value = "收货数量", example = "0")
    public Double recQty;

    @ApiParam(value = "供应商名称")
    @Transient
    public String vendorNameRdd;

    @ApiParam(value = "项目名称")
    @Transient
    public String prodCfgTypeName;

    @ApiParam(value = "标签编号")
    @Transient
    public String labelNo;

    @ApiParam(value = "送货批号")
    @Transient
    public String lotNo;

    @Transient
    @ApiParam(value = "生产日期")
    public String dateCode;

    @Transient
    @ApiParam(value = "订单号")
    public String refSrc;

    @Transient
    @ApiParam(value = "条码")
    public String sn;

    @Transient
    @ApiParam(value = "工厂名称")
    public String organizeName;

    @Transient
    @ApiParam(value = "最早收货时间")
    public String earliestReceTime;

    @Transient
    @ApiParam(value = "最晚收货时间")
    public String latestReceTime;

    public WmsPoSn(){}

    public WmsPoSn(String orderNo,String earliestReceTime,String latestReceTime){
        this.orderNo = orderNo;
        this.earliestReceTime = earliestReceTime;
        this.latestReceTime = latestReceTime;
    }
}
